smartcard.wx.SimpleSCardAppFrame.BlankPanel

# ``smartcard`.`wx`.`SimpleSCardAppFrame`.`BlankPanel``

class documentation

`class BlankPanel(wx.Panel, SimpleSCardAppEventObserver):`

View In Hierarchy

A blank panel in case no panel is provided to SimpleSCardApp.

Method | `__init__` | Undocumented

Inherited from `SimpleSCardAppEventObserver`:

Method | `OnActivateCard` | Called when a card is activated in the reader tree control or toolbar.
Method | `OnActivateReader` | Called when a reader is activated in the reader tree control or toolbar.
Method | `OnDeactivateCard` | Called when a card is deactivated in the reader tree control or toolbar.
Method | `OnDeselectCard` | Called when a card is selected in the reader tree control or toolbar.
Method | `OnSelectCard` | Called when a card is selected in the reader tree control or toolbar.
Method | `OnSelectReader` | Called when a reader is selected in the reader tree control or toolbar.
Instance Variable | `selectedcard` | Undocumented
Instance Variable | `selectedreader` | Undocumented

def __init__(self, parent):
overrides `smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.__init__`

Undocumented